#' @importFrom stats predict rnorm
NULL

#' Map a normalised vector of parameters from the unit cube to its natural space
#'
#' @param x A normalised vector of parameters
#' @param Bounds a length(x)*2 matrix with lower and upper bounds for each dimension of x
#'
#' @return a vector in the space, the bounds of which given in Bounds
#' @export
#'
#' @examples
#' Bounds = matrix(c(10,20,90,500,1,6),nrow=3,ncol=2,byrow=TRUE)
#' theta = rep(.5,3)
#' unNormalise = unNormalise(theta,Bounds)
unNormalise = function(x, Bounds) {
  vec = FALSE
  if (is.null(dim(x))) {
    x = matrix(x, nrow = 1)
    vec = TRUE
  }
  res = sapply(1:ncol(x), function(k)
    x[, k] * (Bounds[k, 2] - Bounds[k, 1]) + Bounds[k, 1])
  if (vec)
    res = as.vector(res)

  res
}

#' Map a vector of parameters from its natural space to the unit cube
#'
#' @param x a vector of parameters
#' @param Bounds a length(x)*2 matrix with lower and upper bounds for each dimension of x
#'
#' @return a vector in the unit cube
#' @export
#'
#' @examples
#' Bounds = matrix(c(10,20,90,500,1,6),nrow=3,ncol=2,byrow=TRUE)
#' theta = c(12,450,2)
#' Normalise = unNormalise(theta,Bounds)
Normalise = function(x, Bounds) {
  vec = FALSE
  if (is.null(dim(x))) {
    x = matrix(x, nrow = 1)
    vec = TRUE
  }
  res = sapply(1:ncol(x), function(k)
    (x[k] - Bounds[k, 1]) / (Bounds[k, 2] - Bounds[k, 1]))
  if (vec)
    res = as.vector(res)

  res

}



