% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/calibration.R
\name{approxlogpost}
\alias{approxlogpost}
\title{Compute log posterior distribution via a Kriging Metamodel approximation}
\usage{
approxlogpost(thetaN, logy, krig1s, sigma2 = 0.1^2)
}
\arguments{
\item{thetaN}{vector of parameters to calibrate}

\item{logy}{log of biomass observations}

\item{krig1s}{list of km object for Kriging metamodels for the same season and different observation time}

\item{sigma2}{variance of the observational noise}
}
\value{
value of the log posterior distribution
}
\description{
Compute log posterior distribution via a Kriging Metamodel approximation
}
\examples{
## Kriging approximation
Bounds  = matrix(c(600,1000,1300,1800,1,6),nrow=3,ncol=2,byrow=TRUE)
D = DiceDesign::lhsDesign(30, 3)$design
Dun = unNormalise(D,Bounds )
met <- BuildMeteodat("2008-2009")
nT=3
times = seq(160,305,length=nT)
y = t(sapply(1:nrow(Dun), function(i) fbiomass(200,met,Dun[i,])[times]))
y = log(y)
krig1s = lapply(1:ncol(y), function(k){
m <- DiceKriging::km(design=D, response=y[,k],nugget = .1,control=list(trace=FALSE))
return(m)})
## Computation of the log posterior distribution
Bounds  = matrix(c(600,1000,1300,1800,1,6),nrow=3,ncol=2,byrow=TRUE)
nT=3
times = seq(160,305,length=nT)
approxlogpost(Normalise(c(800,1600,3),Bounds),fbiomass(200,met,c(800,1600,3))[times]+rnorm(nT,0,sqrt(.1)),krig1s,sigma2=.1)
}
