% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/calibration.R
\name{approxlogpostMulti}
\alias{approxlogpostMulti}
\title{Compute log posterior distribution via a Kriging Metamodel approximation for several datasets observed during different seasons}
\usage{
approxlogpostMulti(thetaN, listlogy, krig, sigma2)
}
\arguments{
\item{thetaN}{vector of parameters to calibrate}

\item{listlogy}{list of observed biomass for different seasons}

\item{krig}{list of lists of krig for different seasons}

\item{sigma2}{variance of the observational noise}
}
\value{
value of the log posterior distribution
}
\description{
Compute log posterior distribution via a Kriging Metamodel approximation for several datasets observed during different seasons
}
\examples{
## Kriging approximation
Bounds  = matrix(c(600,1000,1300,1800,1,6),nrow=3,ncol=2,byrow=TRUE)
D = DiceDesign::lhsDesign(30, 3)$design
Dun = unNormalise(D,Bounds )
met0809 <- BuildMeteodat("2008-2009")
met0910 <- BuildMeteodat("2009-2010")
nT=3
times = seq(160,305,length=nT)
y = t(sapply(1:nrow(Dun), function(i) fbiomass(200,met0809,Dun[i,])[times]))
y = log(y)
krig1 = lapply(1:ncol(y), function(k){
m <- DiceKriging::km(design=D, response=y[,k],nugget = .1,control=list(trace=FALSE))
return(m)})
y = t(sapply(1:nrow(Dun), function(i) fbiomass(200,met0910,Dun[i,])[times]))
y = log(y)
krig2 = lapply(1:ncol(y), function(k){
m <- DiceKriging::km(design=D, response=y[,k],nugget = .1,control=list(trace=FALSE))
return(m)})
krig = list(krig1,krig2)
 ## Computation of the log posterior distribution
Bounds  = matrix(c(600,1000,1300,1800,1,6),nrow=3,ncol=2,byrow=TRUE)
nT=3
times = seq(160,305,length=nT)
listlogy = list(fbiomass(200,met0809,c(800,1600,3))[times]+rnorm(nT,0,sqrt(.1)),fbiomass(200,met0910,c(800,1600,3))[times]+rnorm(nT,0,sqrt(.1)))
approxlogpostMulti(Normalise(c(800,1600,3),Bounds),listlogy,krig,sigma2=.1)
}
