% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/calibration.R
\name{computeSS}
\alias{computeSS}
\title{Compute the squared differences between observations and outputs of the FSPM}
\usage{
computeSS(krig, logy, sigma2)
}
\arguments{
\item{krig}{list of lists of krig for different seasons}

\item{logy}{list of observed biomass for different seasons}

\item{sigma2}{variance of the observational noise}
}
\value{
a matrix with n rows and d columns of the squared differences between the d observed biomass for the n calls made to build the Kriging design
}
\description{
Compute the squared differences between observations and outputs of the FSPM
}
\examples{
## Kriging approximation
Bounds  = matrix(c(600,1000,1300,1800,1,6),nrow=3,ncol=2,byrow=TRUE)
D = DiceDesign::lhsDesign(30, 3)$design
Dun = unNormalise(D,Bounds )
met0809 <- BuildMeteodat("2008-2009")
met0910 <- BuildMeteodat("2009-2010")
nT=3
times = seq(160,305,length=nT)
y = t(sapply(1:nrow(Dun), function(i) fbiomass(200,met0809,Dun[i,])[times]))
y = log(y)
krig1 = lapply(1:ncol(y), function(k){
m <- DiceKriging::km(design=D, response=y[,k],nugget = .1,control=list(trace=FALSE))
return(m)})
y = t(sapply(1:nrow(Dun), function(i) fbiomass(200,met0910,Dun[i,])[times]))
y = log(y)
krig2 = lapply(1:ncol(y), function(k){
m <- DiceKriging::km(design=D, response=y[,k],nugget = .1,control=list(trace=FALSE))
return(m)})
krig = list(krig1,krig2)
 ## Computation of the log posterior distribution
Bounds  = matrix(c(600,1000,1300,1800,1,6),nrow=3,ncol=2,byrow=TRUE)
nT=3
times = seq(160,305,length=nT)
listlogy = list(fbiomass(200,met0809,c(800,1600,3))[times]+rnorm(nT,0,sqrt(.1)),fbiomass(200,met0910,c(800,1600,3))[times]+rnorm(nT,0,sqrt(.1)))
computeSS(krig,listlogy,.1)
}
