% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/prediction.R
\name{predictApprox}
\alias{predictApprox}
\title{Probabilistic prediction from a distribution of theta and Kriging metamodel}
\usage{
predictApprox(krig1s, distribtheta)
}
\arguments{
\item{krig1s}{Kriging metamodel for a given season}

\item{distribtheta}{sample of parameters in the unit cube}
}
\value{
a list with predictions and associated sd for each element of the sample (log scale)
}
\description{
Probabilistic prediction from a distribution of theta and Kriging metamodel
}
\examples{
Bounds  = matrix(c(600,1000,1300,1800,1,6),nrow=3,ncol=2,byrow=TRUE)
D = DiceDesign::lhsDesign(30, 3)$design
Dun = unNormalise(D,Bounds )
met <- BuildMeteodat("2008-2009")
nT=10
times = seq(160,305,length=nT)
y = t(sapply(1:nrow(Dun), function(i) fbiomass(200,met,Dun[i,])[times]))
y = log(y)
krig1s = lapply(1:ncol(y), function(k){
m <- DiceKriging::km(design=D, response=y[,k],nugget = .01,control=list(trace=FALSE))
return(m)})
dtheta = matrix(runif(300,.4,.45),100,3)
PredA = predictApprox(krig1s,dtheta)
meanPred = predictmultdim(apply(dtheta,2,mean),krig1s)
# Plot mean predicted biomas with Kriging uncertainties
plot(met$cumdegree[times],exp(meanPred[1,]),ylab="biomass",ylim=c(0,14))
arrows(met$cumdegree[times], exp(meanPred[1,]-1.64*meanPred[2,]),met$cumdegree[times], exp(meanPred[1,]+1.64*meanPred[2,]), length=0.05, angle=90, code=3)
# compute quantiles with uncertainties on parameters
Simus = sapply(1:ncol(PredA$Mpred),function(k){
                          Sim = PredA$Mpred[,k] + rnorm(1000,0,PredA$Spred[,k])})
q5 = apply(Simus,2,quantile,.05) ; q95 = apply(Simus,2,quantile,.95)
lines(met$cumdegree[times],exp(q5),lty=2) ; lines(met$cumdegree[times],exp(q95),lty=2)
legend("topleft",legend=c("mean prediction with Kriging uncertainty","quantiles .05 and .95, full uncertainty"),pch=c(1,NA),lty=c(0,2))
}
