% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/EGO.R
\name{runEGO}
\alias{runEGO}
\title{Enhance the Kriging metamodel for calibration according to the EGO criterion}
\usage{
runEGO(
  krig,
  logy,
  sigma2,
  x,
  seasons,
  Bounds,
  times,
  nEI = 5,
  npoints = 100,
  nsim = 100
)
}
\arguments{
\item{krig}{list of lists of krig for different seasons}

\item{logy}{list of observed biomass for different seasons}

\item{sigma2}{variance of the observational noise}

\item{x}{sowing density}

\item{seasons}{a list with the names of the considered seasons}

\item{Bounds}{length(x)*2 matrix with lower and upper bounds for each dimension of x}

\item{times}{times of observations}

\item{nEI}{number of points to add}

\item{npoints}{design points to try}

\item{nsim}{number of simulations used to compute the EI}
}
\value{
a list with the updated krig metamodel, the sum of the minimal values, the value of the EI criterion for the added points
}
\description{
Enhance the Kriging metamodel for calibration according to the EGO criterion
}
\examples{
#'  ## Kriging approximation
Bounds  = matrix(c(600,1000,1300,1800,1,6),nrow=3,ncol=2,byrow=TRUE)
D = DiceDesign::lhsDesign(30, 3)$design
Dun = unNormalise(D,Bounds )
met0809 <- BuildMeteodat("2008-2009")
met0910 <- BuildMeteodat("2009-2010")
nT=3
times = seq(160,305,length=nT)
y = t(sapply(1:nrow(Dun), function(i) fbiomass(200,met0809,Dun[i,])[times]))
y = log(y)
krig1 = lapply(1:ncol(y), function(k){
m <- DiceKriging::km(design=D, response=y[,k],nugget = .1,control=list(trace=FALSE))
return(m)})
y = t(sapply(1:nrow(Dun), function(i) fbiomass(200,met0910,Dun[i,])[times]))
y = log(y)
krig2 = lapply(1:ncol(y), function(k){
m <- DiceKriging::km(design=D, response=y[,k],nugget = .1,control=list(trace=FALSE))
return(m)})
krig = list(krig1,krig2)
## new simu to add
yX = lapply(krig,function(krigseason){
temp=sapply(1:length(krigseason),function(k){krigseason[[k]]@y})
temp
})
listlogy = list(fbiomass(200,met0809,c(800,1600,3))[times]+rnorm(nT,0,sqrt(.1)),fbiomass(200,met0910,c(800,1600,3))[times]+rnorm(nT,0,sqrt(.1)))
updatedKrig = runEGO(krig,listlogy,.1,200,list("2008-2009","2009-2010"),Bounds,times,1,10,50)
}
